@@ -26,15 +26,21 @@ class UBXReader:
     UBXReader class.
     """
 
-    def __init__(self, stream, validate=False):
+    def __init__(self, stream, validate: bool = False, mode: int = 0):
         """Constructor.
 
-        :param stream: stream
-        :param validate: bool
+        :param stream stream: input data stream
+        :param bool validate: validate (y/n)
+        :param int mode: message mode (0=GET, 1=SET, 2=POLL)
+        :raise UBXStreamError
         """
 
+        if mode not in (0, 1, 2):
+            raise UBXStreamError(f"Invalid stream mode {mode} - must be 0, 1 or 2")
+
         self._stream = stream
         self._validate = validate
+        self._mode = mode
 
     def __iter__(self):
         """Iterator."""
@@ -88,7 +94,7 @@ class UBXReader:
                 plb = byten[0:leni]
                 cksum = byten[leni : leni + 2]
                 raw_data = ubt.UBX_HDR + clsid + msgid + lenb + plb + cksum
-                parsed_data = UBXMessage.parse(raw_data)
+                parsed_data = UBXMessage.parse(raw_data, False, self._mode)
                 reading = False
             else:  # it's not a UBX message
                 if self._validate:  # raise error and quit
